package com.qianhe.service;

import com.qianhe.common.core.domain.TreeSelect;
import com.qianhe.common.core.domain.entity.SysDept;
import com.qianhe.domain.SjGfjsBfzbfdx;
import com.qianhe.domain.SjGfjsBfzwh;

import java.util.List;


/**
 * 三基帮扶组维护Service接口
 *
 * @author qianhe
 * @date 2024-08-31
 */
public interface ISjGfjsBfzwhService
{
    /**
     * 查询三基帮扶组维护
     *
     * @param id 三基帮扶组维护主键
     * @return 三基帮扶组维护
     */
    public SjGfjsBfzwh selectSjGfjsBfzwhById(Long id);

    public SjGfjsBfzwh selectbfz(String lxr);

    /**
     * 查询三基帮扶组维护列表
     *
     * @param sjGfjsBfzwh 三基帮扶组维护
     * @return 三基帮扶组维护集合
     */
    public List<SjGfjsBfzwh> selectSjGfjsBfzwhList(SjGfjsBfzwh sjGfjsBfzwh);

    /**
     * 新增三基帮扶组维护
     *
     * @param sjGfjsBfzwh 三基帮扶组维护
     * @return 结果
     */
    public int insertSjGfjsBfzwh(SjGfjsBfzwh sjGfjsBfzwh);

    /**
     * 修改三基帮扶组维护
     *
     * @param sjGfjsBfzwh 三基帮扶组维护
     * @return 结果
     */
    public int updateSjGfjsBfzwh(SjGfjsBfzwh sjGfjsBfzwh);

    /**
     * 批量删除三基帮扶组维护
     *
     * @param ids 需要删除的三基帮扶组维护主键集合
     * @return 结果
     */
    public int deleteSjGfjsBfzwhByIds(Long[] ids);

    /**
     * 删除三基帮扶组维护信息
     *
     * @param id 三基帮扶组维护主键
     * @return 结果
     */
    public int deleteSjGfjsBfzwhById(Long id);


    /**
     * 查询三基帮扶组帮扶对象
     *
     * @param id 三基帮扶组维护主键
     * @return 三基帮扶组维护
     */
    public List<Long>  selectBfdxListByBfz(Long id);

    /**
     * 构建前端所需要下拉树结构
     *
     * @param depts 单位列表
     * @return 下拉树结构列表
     */
    public List<TreeSelect> buildBfdwTreeSelect(List<SysDept> depts);
    public List<SysDept> buildBfdwxTree(List<SysDept> menus);

    public List<SjGfjsBfzbfdx>  selectBfdxlist(SjGfjsBfzbfdx sjGfjsBfzbfdx);
}
